import dash
from dash import dcc
from dash import html
from dash.dependencies import Input, Output

app = dash.Dash(__name__)

list_of_inputs = dict()

app.layout = html.Div([
    html.H4("Add all lines in a file to a list"),
    html.Div([
        dcc.Upload(
            id="upload-data",
            children=html.Div(
                ["Drag and drop or click to select a file to upload."]
            ),
            style={
                "width": "30%",
                "height": "60px",
                "lineHeight": "60px",
                "borderWidth": "1px",
                "borderStyle": "dashed",
                "borderRadius": "5px",
                "textAlign": "center",
                "margin": "10px",
            }),
        dcc.Checklist(id='list-of-inputs',labelStyle = dict(display='block'))
    ]),
])

@app.callback(
    Output('list-of-inputs','options'),
    Input('upload-data','filenames'),
    Input('upload-data','contents')
)
def update_input_list(uploaded_filenames,uploaded_file_contents):
    for line in uploaded_file_contents:
        line = line.rstrip()
        list_of_inputs[line] = line
    try:
        stream = open(uploaded_filenames,'r') # this statement may throw an exception
    except IOError as err: # exception stores error message in err
        # now comes the code reacting on the exception
        sys.stderr.write('{}: {}\n'.format(sys.argv[0], err))
        exit(1)
    return [{'label': i, 'value': i} for i in list_of_inputs], ''

if __name__ == '__main__':
    app.run_server(debug=True)

